summaryrefslogtreecommitdiff
path: root/test
diff options
context:
space:
mode:
Diffstat (limited to 'test')
-rw-r--r--test/reels_test.cc5
1 files changed, 2 insertions, 3 deletions
diff --git a/test/reels_test.cc b/test/reels_test.cc
index 9e8e120a6..b8a0b0a60 100644
--- a/test/reels_test.cc
+++ b/test/reels_test.cc
@@ -238,8 +238,8 @@ BOOST_AUTO_TEST_CASE (reels_test5)
film->examine_and_add_content (dcp);
wait_for_jobs ();
- /* Set to 123 but it will be rounded up to the next frame (4000) */
- dcp->set_position(DCPTime(123));
+ /* Set to 2123 but it will be rounded up to the next frame (4000) */
+ dcp->set_position(DCPTime(2123));
{
list<DCPTimePeriod> p = dcp->reels ();
@@ -342,7 +342,6 @@ BOOST_AUTO_TEST_CASE (reels_test8)
BOOST_REQUIRE (!wait_for_jobs ());
A->set_trim_end (ContentTime::from_seconds (1));
- cout << to_string(A->length_after_trim()) << "\n";
film->make_dcp ();
BOOST_REQUIRE (!wait_for_jobs ());
}